==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/foundations/foundation-protobuf/src/test/java/org/apache/servicecomb/foundation/protobuf/internal/parser/TestProtoParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.protobuf.internal.parser;

import java.io.IOException;
import java.net.URL;
import java.nio.charset.StandardCharsets;

import org.apache.commons.io.IOUtils;
import org.junit.Assert;
import org.junit.Test;

import com.google.common.base.MoreObjects;

import io.protostuff.compiler.model.Proto;

public class TestProtoParser {
  @Test
  public void parse() throws IOException {
    URL url = Thread.currentThread().getContextClassLoader().getResource("protobufRoot.proto");
    String content = IOUtils.toString(url, StandardCharsets.UTF_8);

    ProtoParser parser = new ProtoParser();
    Proto protoFromContent = parser.parseFromContent(content);
    Proto protoFromName = parser.parse("protobufRoot.proto");

    Assert.assertNotNull(protoFromContent.getMessage("Root"));
    Assert.assertNotNull(protoFromContent.getMessage("User"));

    Assert.assertEquals(MoreObjects.toStringHelper(protoFromContent)
            .omitNullValues()
            .add("messages", protoFromContent.getMessages())
            .toString(),
        MoreObjects.toStringHelper(protoFromName)
            .omitNullValues()
            .add("messages", protoFromName.getMessages())
            .toString());
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.16-src.zip: apache-servicecomb-java-chassis-distribution-2.8.16-src/foundations/foundation-protobuf/src/test/java/org/apache/servicecomb/foundation/protobuf/internal/parser/TestProtoParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.foundation.protobuf.internal.parser;

import com.google.common.base.MoreObjects;
import io.protostuff.compiler.model.Proto;
import org.apache.commons.io.IOUtils;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.net.URL;
import java.nio.charset.StandardCharsets;

public class TestProtoParser {
  @Test
  public void parse() throws IOException {
    URL url = Thread.currentThread().getContextClassLoader().getResource("protobufRoot.proto");
    String content = IOUtils.toString(url, StandardCharsets.UTF_8);

    ProtoParser parser = new ProtoParser();
    Proto protoFromContent = parser.parseFromContent(content);
    Proto protoFromName = parser.parse("protobufRoot.proto");

    Assertions.assertNotNull(protoFromContent.getMessage("Root"));
    Assertions.assertNotNull(protoFromContent.getMessage("User"));

    Assertions.assertEquals(MoreObjects.toStringHelper(protoFromContent)
            .omitNullValues()
            .add("messages", protoFromContent.getMessages())
            .toString(),
        MoreObjects.toStringHelper(protoFromName)
            .omitNullValues()
            .add("messages", protoFromName.getMessages())
            .toString());
  }
}
